==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/awscdk/AutoDiscover.java <==
package io.github.cdklabs.projen.awscdk;

/**
 * (experimental) Automatically creates a `LambdaFunction` for all `.lambda.ts` files under the source directory of the project.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.461Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.awscdk.AutoDiscover")
public class AutoDiscover extends io.github.cdklabs.projen.Component {

    protected AutoDiscover(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AutoDiscover(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public AutoDiscover(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.awscdk.AutoDiscoverOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.awscdk.AutoDiscover}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.awscdk.AutoDiscover> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.awscdk.AutoDiscoverOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.awscdk.AutoDiscoverOptions.Builder();
        }

        /**
         * (experimental) AWS CDK dependency manager.
         * <p>
         * @return {@code this}
         * @param cdkDeps AWS CDK dependency manager. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder cdkDeps(final io.github.cdklabs.projen.awscdk.AwsCdkDeps cdkDeps) {
            this.options.cdkDeps(cdkDeps);
            return this;
        }

        /**
         * (experimental) Project source tree (relative to project output directory).
         * <p>
         * @return {@code this}
         * @param srcdir Project source tree (relative to project output directory). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder srcdir(final java.lang.String srcdir) {
            this.options.srcdir(srcdir);
            return this;
        }

        /**
         * (experimental) Test source tree.
         * <p>
         * @return {@code this}
         * @param testdir Test source tree. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder testdir(final java.lang.String testdir) {
            this.options.testdir(testdir);
            return this;
        }

        /**
         * (experimental) Path to the tsconfig file to use for integration tests.
         * <p>
         * @return {@code this}
         * @param tsconfigPath Path to the tsconfig file to use for integration tests. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tsconfigPath(final java.lang.String tsconfigPath) {
            this.options.tsconfigPath(tsconfigPath);
            return this;
        }

        /**
         * (experimental) Options for auto-discovery of AWS Lambda functions.
         * <p>
         * @return {@code this}
         * @param lambdaOptions Options for auto-discovery of AWS Lambda functions. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder lambdaOptions(final io.github.cdklabs.projen.awscdk.LambdaFunctionCommonOptions lambdaOptions) {
            this.options.lambdaOptions(lambdaOptions);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.awscdk.AutoDiscover}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.awscdk.AutoDiscover build() {
            return new io.github.cdklabs.projen.awscdk.AutoDiscover(
                this.project,
                this.options.build()
            );
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/awscdk/AutoDiscover.java <==
package io.github.cdklabs.projen.awscdk;

/**
 * (experimental) Discovers and creates integration tests and lambdas from code in the project's source and test trees.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.168Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.awscdk.AutoDiscover")
public class AutoDiscover extends io.github.cdklabs.projen.Component {

    protected AutoDiscover(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AutoDiscover(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public AutoDiscover(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.awscdk.AutoDiscoverOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.awscdk.AutoDiscover}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.awscdk.AutoDiscover> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.awscdk.AutoDiscoverOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.awscdk.AutoDiscoverOptions.Builder();
        }

        /**
         * (experimental) AWS CDK dependency manager.
         * <p>
         * @return {@code this}
         * @param cdkDeps AWS CDK dependency manager. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder cdkDeps(final io.github.cdklabs.projen.awscdk.AwsCdkDeps cdkDeps) {
            this.options.cdkDeps(cdkDeps);
            return this;
        }

        /**
         * (experimental) Path to the tsconfig file to use for integration tests.
         * <p>
         * @return {@code this}
         * @param tsconfigPath Path to the tsconfig file to use for integration tests. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tsconfigPath(final java.lang.String tsconfigPath) {
            this.options.tsconfigPath(tsconfigPath);
            return this;
        }

        /**
         * (experimental) Project source tree (relative to project output directory).
         * <p>
         * @return {@code this}
         * @param srcdir Project source tree (relative to project output directory). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder srcdir(final java.lang.String srcdir) {
            this.options.srcdir(srcdir);
            return this;
        }

        /**
         * (experimental) Options for AWS Lambda functions.
         * <p>
         * @return {@code this}
         * @param lambdaOptions Options for AWS Lambda functions. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder lambdaOptions(final io.github.cdklabs.projen.awscdk.LambdaFunctionCommonOptions lambdaOptions) {
            this.options.lambdaOptions(lambdaOptions);
            return this;
        }

        /**
         * (experimental) Options for lambda extensions.
         * <p>
         * @return {@code this}
         * @param lambdaExtensionOptions Options for lambda extensions. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder lambdaExtensionOptions(final io.github.cdklabs.projen.awscdk.LambdaExtensionCommonOptions lambdaExtensionOptions) {
            this.options.lambdaExtensionOptions(lambdaExtensionOptions);
            return this;
        }

        /**
         * (experimental) Test source tree.
         * <p>
         * @return {@code this}
         * @param testdir Test source tree. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder testdir(final java.lang.String testdir) {
            this.options.testdir(testdir);
            return this;
        }

        /**
         * (experimental) Options for integration tests.
         * <p>
         * @return {@code this}
         * @param integrationTestOptions Options for integration tests. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder integrationTestOptions(final io.github.cdklabs.projen.awscdk.IntegrationTestCommonOptions integrationTestOptions) {
            this.options.integrationTestOptions(integrationTestOptions);
            return this;
        }

        /**
         * (experimental) Auto-discover edge lambda functions.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param edgeLambdaAutoDiscover Auto-discover edge lambda functions. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder edgeLambdaAutoDiscover(final java.lang.Boolean edgeLambdaAutoDiscover) {
            this.options.edgeLambdaAutoDiscover(edgeLambdaAutoDiscover);
            return this;
        }

        /**
         * (experimental) Auto-discover integration tests.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param integrationTestAutoDiscover Auto-discover integration tests. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder integrationTestAutoDiscover(final java.lang.Boolean integrationTestAutoDiscover) {
            this.options.integrationTestAutoDiscover(integrationTestAutoDiscover);
            return this;
        }

        /**
         * (experimental) Auto-discover lambda functions.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param lambdaAutoDiscover Auto-discover lambda functions. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder lambdaAutoDiscover(final java.lang.Boolean lambdaAutoDiscover) {
            this.options.lambdaAutoDiscover(lambdaAutoDiscover);
            return this;
        }

        /**
         * (experimental) Auto-discover lambda extensions.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param lambdaExtensionAutoDiscover Auto-discover lambda extensions. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder lambdaExtensionAutoDiscover(final java.lang.Boolean lambdaExtensionAutoDiscover) {
            this.options.lambdaExtensionAutoDiscover(lambdaExtensionAutoDiscover);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.awscdk.AutoDiscover}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.awscdk.AutoDiscover build() {
            return new io.github.cdklabs.projen.awscdk.AutoDiscover(
                this.project,
                this.options.build()
            );
        }
    }
}
